==> haskell-safesemaphore-0.10.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SafeSemaphore
version: 0.10.1
id: SafeSemaphore-0.10.1-7K4NMXAF59B7yv7AR4Jww7
key: SafeSemaphore-0.10.1-7K4NMXAF59B7yv7AR4Jww7
license: BSD3
maintainer: Chris Kuklewicz <haskell@list.mightyreason.com>
homepage: https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis: Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.
category: Concurrency
author: Chris Kuklewicz <haskell@list.mightyreason.com>
exposed: True
exposed-modules:
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.MSampleVar
    Control.Concurrent.FairRWLock Control.Concurrent.SSem
    Control.Concurrent.STM.SSem
hidden-modules: Control.Concurrent.STM.SSemInternals
abi: 93fa3d3a002b9b8b0a67b4a82f238230
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/SafeSemaphore-0.10.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/SafeSemaphore-0.10.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/SafeSemaphore-0.10.1
hs-libraries: HSSafeSemaphore-0.10.1-7K4NMXAF59B7yv7AR4Jww7
depends:
    base-4.9.0.0 containers-0.5.7.1 stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
haddock-interfaces: /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock
haddock-html: /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safesemaphore-0.10.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SafeSemaphore
version: 0.10.1
id: SafeSemaphore-0.10.1-4eqsLLtbaAb8p320mhD6jB
key: SafeSemaphore-0.10.1-4eqsLLtbaAb8p320mhD6jB
license: BSD3
maintainer: Chris Kuklewicz <haskell@list.mightyreason.com>
homepage: https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis: Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.
category: Concurrency
author: Chris Kuklewicz <haskell@list.mightyreason.com>
exposed: True
exposed-modules:
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.MSampleVar
    Control.Concurrent.FairRWLock Control.Concurrent.SSem
    Control.Concurrent.STM.SSem
hidden-modules: Control.Concurrent.STM.SSemInternals
abi: ae788525dd06a7e416a79afa2edbfdc6
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/SafeSemaphore-0.10.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/SafeSemaphore-0.10.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/SafeSemaphore-0.10.1
hs-libraries: HSSafeSemaphore-0.10.1-4eqsLLtbaAb8p320mhD6jB
depends:
    base-4.9.1.0 containers-0.5.7.1 stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
haddock-interfaces: /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock
haddock-html: /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
